# BChess

> “I give 98 percent of my mental energy to BChess; others
> give only 2 percent.” —Bobby Fischer

BChess is a beginner-friendly chess in a console, with batteries
included.

<p align="center">
 <img src="https://raw.githubusercontent.com/magv/bchess/master/demo.gif" width="339" height="367"/>
</p>

## How to install

BChess runs under Python 3.6 or newer on Unix-like machines.
You can install or upgrade it to the latest commit from [PyPI]
by running:

    python3 -m pip install --user bchess

[PyPI]: https://pypi.org/project/bchess/

This will install the `bchess` program into `~/.local/bin` folder,
and if that folder is in your `$PATH`, then you will be able to
run BChess by just typing `bchess`. If not, `python3 -m bchess`
should work regardless.

## How to play

> “To play for a draw, at any rate with white, is to some
> degree a crime against BChess.” —Mikhail Tal

Start BChess, select your opponent, click on the piece you want
to move or enter your move in algebraic notation. Try to win.
Or at least have fun.
